@@ -42,6 +42,7 @@ extern char *strdup(const char *);
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
+#include <sys/param.h>
 #include <fcntl.h>
 #include <termios.h>
 #include <errno.h>
@@ -93,13 +94,13 @@ static pty_info *pty_list;
 #endif
 #endif /* CMSG_DATA */
 
-#define CONTROLLEN (sizeof (struct cmsghdr)  + sizeof (int))
-
 static struct cmsghdr *cmptr;
+static int CONTROLLEN;
 
 static int
 init_msg_pass ()
 {
+	CONTROLLEN = (CMSG_DATA (cmptr) - (unsigned char *)cmptr) + sizeof(int);
 	cmptr = malloc (CONTROLLEN);
 
 	if (cmptr)
@@ -654,6 +655,14 @@ sanity_checks (void)
 	}
 }
 
+static void
+exit_handler (int signum)
+{
+	shutdown_helper ();
+	_exit (1);
+}
+
+
 int
 main (int argc, char *argv [])
 {
@@ -675,6 +684,9 @@ main (int argc, char *argv [])
 	if (!display_name)
 		display_name = "localhost";
 
+	/* Make sure we clean up utmp/wtmp even under vncserver */
+	signal (SIGHUP, exit_handler);
+	signal (SIGTERM, exit_handler);
 
 	if (init_msg_pass () == -1)
 		exit (1);
