@@ -19,7 +19,7 @@
 #ifndef vte_vte_h_included
 #define vte_vte_h_included
 
-#ident "$Id: vte.h,v 1.69 2003/06/16 21:15:10 nalin Exp $"
+#ident "$Id: vte.h,v 1.78 2004/05/01 07:12:51 nalin Exp $"
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -63,6 +63,47 @@ struct _VteTerminalClass {
 	/* Inherited parent class. */
 	GtkWidgetClass parent_class;
 
+	/*< protected > */
+	/* Default signal handlers. */
+	void (*eof)(VteTerminal* terminal);
+	void (*child_exited)(VteTerminal* terminal);
+	void (*emulation_changed)(VteTerminal* terminal);
+	void (*encoding_changed)(VteTerminal* terminal);
+	void (*char_size_changed)(VteTerminal* terminal, guint char_width, guint char_height);
+	void (*window_title_changed)(VteTerminal* terminal);
+	void (*icon_title_changed)(VteTerminal* terminal);
+	void (*selection_changed)(VteTerminal* terminal);
+	void (*contents_changed)(VteTerminal* terminal);
+	void (*cursor_moved)(VteTerminal* terminal);
+	void (*status_line_changed)(VteTerminal* terminal);
+	void (*commit)(VteTerminal* terminal, gchar *text, guint size);
+
+	void (*deiconify_window)(VteTerminal* terminal);
+	void (*iconify_window)(VteTerminal* terminal);
+	void (*raise_window)(VteTerminal* terminal);
+	void (*lower_window)(VteTerminal* terminal);
+	void (*refresh_window)(VteTerminal* terminal);
+	void (*restore_window)(VteTerminal* terminal);
+	void (*maximize_window)(VteTerminal* terminal);
+	void (*resize_window)(VteTerminal* terminal, guint width, guint height);
+	void (*move_window)(VteTerminal* terminal, guint x, guint y);
+
+	void (*increase_font_size)(VteTerminal* terminal);
+	void (*decrease_font_size)(VteTerminal* terminal);
+
+	void (*text_modified)(VteTerminal* terminal);
+	void (*text_inserted)(VteTerminal* terminal);
+	void (*text_deleted)(VteTerminal* terminal);
+	void (*text_scrolled)(VteTerminal* terminal, gint delta);
+
+	/* Padding for future expansion. */
+	void (*vte_reserved1)(void);
+	void (*vte_reserved2)(void);
+	void (*vte_reserved3)(void);
+	void (*vte_reserved4)(void);
+	void (*vte_reserved5)(void);
+	void (*vte_reserved6)(void);
+
 	/*< private > */
 	/* Signals we might emit. */
 	guint eof_signal;
@@ -113,6 +154,13 @@ typedef enum {
 	VTE_ERASE_DELETE_SEQUENCE
 } VteTerminalEraseBinding;
 
+/* Values for the anti alias setting */
+typedef enum {
+	VTE_ANTI_ALIAS_USE_DEFAULT,
+	VTE_ANTI_ALIAS_FORCE_ENABLE,
+	VTE_ANTI_ALIAS_FORCE_DISABLE
+} VteTerminalAntiAlias;
+
 /* The structure we return as the supplemental attributes for strings. */
 struct _VteCharAttributes {
 	long row, column;
@@ -131,6 +179,7 @@ struct vte_char_attributes {
 /* The widget's type. */
 GtkType vte_terminal_get_type(void);
 GtkType vte_terminal_erase_binding_get_type(void);
+GtkType vte_terminal_anti_alias_get_type(void);
 
 #define VTE_TYPE_TERMINAL		(vte_terminal_get_type())
 #define VTE_TERMINAL(obj)		(GTK_CHECK_CAST((obj),\
@@ -148,6 +197,9 @@ GtkType vte_terminal_erase_binding_get_type(void);
 #define VTE_TYPE_TERMINAL_ERASE_BINDING	(vte_terminal_erase_binding_get_type())
 #define VTE_IS_TERMINAL_ERASE_BINDING(obj)	GTK_CHECK_TYPE((obj),\
 						VTE_TYPE_TERMINAL_ERASE_BINDING)
+#define VTE_TYPE_TERMINAL_ANTI_ALIAS	(vte_terminal_anti_alias_get_type())
+#define VTE_IS_TERMINAL_ANTI_ALIAS(obj)		GTK_CHECK_TYPE((obj),\
+						VTE_TYPE_TERMINAL_ANTI_ALIAS)
 
 /* You can get by with just these two functions. */
 GtkWidget *vte_terminal_new(void);
@@ -158,6 +210,13 @@ pid_t vte_terminal_fork_command(VteTerminal *terminal,
 				gboolean utmp,
 				gboolean wtmp);
 
+/* Users of libzvt may find this useful. */
+pid_t vte_terminal_forkpty(VteTerminal *terminal,
+			   char **envv, const char *directory,
+			   gboolean lastlog,
+			   gboolean utmp,
+			   gboolean wtmp);
+
 /* Send data to the terminal to display, or to the terminal's forked command
  * to handle in some way.  If it's 'cat', they should be the same. */
 void vte_terminal_feed(VteTerminal *terminal, const char *data, glong length);
@@ -194,6 +253,10 @@ void vte_terminal_set_color_foreground(VteTerminal *terminal,
 				       const GdkColor *foreground);
 void vte_terminal_set_color_background(VteTerminal *terminal,
 				       const GdkColor *background);
+void vte_terminal_set_color_cursor(VteTerminal *terminal,
+				   const GdkColor *cursor_background);
+void vte_terminal_set_color_highlight(VteTerminal *terminal,
+				      const GdkColor *highlight_background);
 void vte_terminal_set_colors(VteTerminal *terminal,
 			     const GdkColor *foreground,
 			     const GdkColor *background,
@@ -225,7 +288,13 @@ void vte_terminal_im_append_menuitems(VteTerminal *terminal,
 /* Set or retrieve the current font. */
 void vte_terminal_set_font(VteTerminal *terminal,
 			   const PangoFontDescription *font_desc);
+void vte_terminal_set_font_full(VteTerminal *terminal,
+				const PangoFontDescription *font_desc,
+				VteTerminalAntiAlias antialias);
 void vte_terminal_set_font_from_string(VteTerminal *terminal, const char *name);
+void vte_terminal_set_font_from_string_full(VteTerminal *terminal,
+					    const char *name,
+					    VteTerminalAntiAlias antialias);
 const PangoFontDescription *vte_terminal_get_font(VteTerminal *terminal);
 gboolean vte_terminal_get_using_xft(VteTerminal *terminal);
 void vte_terminal_set_allow_bold(VteTerminal *terminal, gboolean allow_bold);
@@ -267,6 +336,13 @@ char *vte_terminal_get_text(VteTerminal *terminal,
 						   gpointer data),
 			    gpointer data,
 			    GArray *attributes);
+char *vte_terminal_get_text_include_trailing_spaces(VteTerminal *terminal,
+						    gboolean(*is_selected)(VteTerminal *terminal,
+									   glong column,
+									   glong row,
+									   gpointer data),
+						    gpointer data,
+						    GArray *attributes);
 char *vte_terminal_get_text_range(VteTerminal *terminal,
 				  glong start_row, glong start_col,
 				  glong end_row, glong end_col,
@@ -303,6 +379,7 @@ char *vte_terminal_match_check(VteTerminal *terminal,
 /* Set the emulation type.  Most of the time you won't need this. */
 void vte_terminal_set_emulation(VteTerminal *terminal, const char *emulation);
 const char *vte_terminal_get_emulation(VteTerminal *terminal);
+const char *vte_terminal_get_default_emulation(VteTerminal *terminal);
 
 /* Set the character encoding.  Most of the time you won't need this. */
 void vte_terminal_set_encoding(VteTerminal *terminal, const char *codeset);
