@@ -21,7 +21,7 @@
 #ifndef vte_vteconv_h_included
 #define vte_vteconv_h_included
 
-#ident "$Id: vteconv.h,v 1.1 2003/05/07 21:28:28 nalin Exp $"
+#ident "$Id: vteconv.h,v 1.2 2003/09/11 20:45:03 nalin Exp $"
 
 #include <glib.h>
 
@@ -36,6 +36,15 @@ VteConv _vte_conv_open(const char *target, const char *source);
 size_t _vte_conv(VteConv converter,
 		 gchar **inbuf, gsize *inbytes_left,
 		 gchar **outbuf, gsize *outbytes_left);
+size_t _vte_conv_uc(VteConv converter,
+		    gunichar **inbuf, gsize *inbytes_left,
+		    gchar **outbuf, gsize *outbytes_left);
+size_t _vte_conv_uu(VteConv converter,
+		    gunichar **inbuf, gsize *inbytes_left,
+		    gunichar **outbuf, gsize *outbytes_left);
+size_t _vte_conv_cu(VteConv converter,
+		    gchar **inbuf, gsize *inbytes_left,
+		    gunichar **outbuf, gsize *outbytes_left);
 gint _vte_conv_close(VteConv converter);
 
 G_END_DECLS
