@@ -16,7 +16,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ident "$Id: vtepango.c,v 1.15 2003/06/16 21:15:10 nalin Exp $"
+#ident "$Id: vtepango.c,v 1.17 2005/07/25 08:49:42 kmaraas Exp $"
 
 #include "../config.h"
 
@@ -67,6 +67,7 @@ _vte_pango_create(struct _vte_draw *draw, GtkWidget *widget)
 	data->font = NULL;
 	data->layout = NULL;
 	data->gc = NULL;
+	data->ctx = NULL;
 }
 
 static void
@@ -258,7 +259,8 @@ _vte_pango_clear(struct _vte_draw *draw,
 
 static void
 _vte_pango_set_text_font(struct _vte_draw *draw,
-			 const PangoFontDescription *fontdesc)
+			 const PangoFontDescription *fontdesc,
+			 VteTerminalAntiAlias antialias)
 {
 #if GTK_CHECK_VERSION(2,2,0)
 	GdkScreen *screen;
